%% load
load VmData
%% Fig. 7c: Plot Vm probe responses: Detect Inside vs Outside RF

figure; 
hold on
y1 = smooth(nanmean(cell2mat(cellfun(@nanmean,[inRF.bCorrect inRF.wCorrect]','UniformOutput',0))),'rloess');
y1err = smooth(nanmean(cell2mat(cellfun(@nanstd,[inRF.bCorrect inRF.wCorrect]','UniformOutput',0))),'rloess')./sqrt(12);
plot(y1,'b')
plot(y1+y1err,'b','Linewidth',0.5)
plot(y1-y1err,'b','Linewidth',0.5)


hold on
y3 = smooth(nanmean(cell2mat(cellfun(@nanmean,[outRF.bCorrect outRF.wCorrect]','UniformOutput',0))),'rloess');
y3err = smooth(nanmean(cell2mat(cellfun(@nanstd,[outRF.bCorrect outRF.wCorrect]','UniformOutput',0))),'rloess')./sqrt(12);
plot(y3,'k')
plot(y3+y3err,'k','Linewidth',0.5)
plot(y3-y3err,'k','Linewidth',0.5)

ylim([-70 -58])
xlim([5 250])

%% Fig. 7d - Probe-evoked depolarization
% DC and probe evoked components
vmOutArray = cell2mat(cellfun(@nanmean,[outRF.bCorrect outRF.wCorrect]','UniformOutput',0));
vmInArray = cell2mat(cellfun(@nanmean,[inRF.bCorrect inRF.wCorrect]','UniformOutput',0));

idx = nchoosek([1:12],11);

for i = 1:length(idx)
DC(i,:) = nanmean(vmInArray(idx(i,:),5:75)) - nanmean(vmOutArray(idx(i,:),5:75));
T(i,:) = nanmean(vmInArray(idx(i,:),100:200)) - nanmean(vmOutArray(idx(i,:),100:200));
T_out(i,:) = nanmean(vmOutArray(idx(i,:),100:200))- nanmean(nanmean(vmOutArray(idx(i,:),100)));
T_in(i,:) = nanmean(vmInArray(idx(i,:),100:200))- nanmean(nanmean(vmInArray(idx(i,:),100)));
end

[nanmean(nanmean(DC,2)) nanstd(nanmean(DC,2))] %tonic component mean +/- SD
[nanmean(nanmax(T,[],2))-nanmean(nanmean(T(:,1:20),2)) nanstd(nanmax(T,[],2))] %transient component

[nanmean(nanmax(T_out(:,1:50),[],2)) nanstd(nanmax(T_out(:,1:50),[],2))] %delta transient component out
[nanmean(nanmax(T_in(:,1:50),[],2)) nanstd(nanmax(T_in(:,1:50),[],2))] %delta transient component in

signtest(nanmax(T,[],2)-nanmean(DC,2)) % transient component diff. from zero
signtest(nanmean(DC,2)) %DC component difference from zero
signrank(nanmax(T_out(:,1:50)),nanmax(T_in(:,1:50))); %T_out vs T_in

% errorbar plots of transient component outside versus inside
figure;
hold on
errorbar(1,nanmean(nanmax(T_out(:,1:50),[],2)),nanstd(nanmax(T_out(:,1:50),[],2)),'k')
errorbar(2,nanmean(nanmax(T_in(:,1:50),[],2)),nanstd(nanmax(T_in(:,1:50),[],2)),'k')
bar(1,nanmean(nanmax(T_out(:,1:50),[],2)),'FaceColor','none')
bar(2,nanmean(nanmax(T_in(:,1:50),[],2)),'FaceColor','none')
y1 = nanmax(T_out(:,1:50),[],2);
y2 = nanmax(T_in(:,1:50),[],2);
for i = 1:length(y1)
line([1 2],[y1(i) y2(i)],'color',[0.5 0.5 0.5])
end
xlim([0 3])
set(gca,'xtick',[1 2])
set(gca,'ytick',[0.5:0.5:2])
ylabel('\Delta mV (probe)')
set(gca,'xticklabel',{'Out','In'})
axis('square')
set(gca,'tickdir','out')
set(gca,'box','off')

[nanmean((nanmax(T_in(:,1:50),[],2) - nanmax(T_out(:,1:50),[],2))./nanmax(T_out(:,1:50),[],2)) ...
(nanstd((nanmax(T_in(:,1:50),[],2) - nanmax(T_out(:,1:50),[],2))./nanmax(T_out(:,1:50),[],2)))./sqrt(12)]

%% Fig. 7D - VM SD histograms
figure;
hold on
plot(2.5,inRF.VmSD_in,'o','color',[0.75 0.75 0.75])
plot(0.5,outRF.VmSD_out,'o','color',[0.75 0.75 0.75])
% plot(1,y1,'x','Color',[0.75 0.75 0.75])
errorbar(2,nanmean(inRF.VmSD_in),nanstd(inRF.VmSD_in)./sqrt(numel(inRF.VmSD_in)),'k')
bar(2,nanmean(inRF.VmSD_in),'EdgeColor','k','FaceColor','none')
% plot(2,y2,'x','Color',[0.75 0.75 0.75])
errorbar(1,nanmean(outRF.VmSD_out),nanstd(outRF.VmSD_out)./sqrt(numel(outRF.VmSD_out)),'k')
bar(1,nanmean(outRF.VmSD_out),'EdgeColor','k','FaceColor','none')
ylim([0 6])
xlim([0 3])
ylabel('V_m SD')
set(gca,'XTick',[1 2])
set(gca,'XTickLabel',{'Detect Outside RF';'Detect Inside RF'})
p = ranksum(outRF.VmSD_out,inRF.VmSD_in,'tail','left');
text(1.25,2.8,strcat('p=',num2str(p)))
axis('square')